import { drizzle } from 'drizzle-orm/vercel-postgres';
import { sql } from "@vercel/postgres";
import {
  PgTimestamp,
  index,
  pgTableCreator,
  serial,
  text,
  timestamp,
  uniqueIndex,
  uuid,
  varchar,
} from "drizzle-orm/pg-core";

/**
 * This is an example of how to use the multi-project schema feature of Drizzle ORM. Use the same
 * database instance for multiple projects.
 *
 * @see https://orm.drizzle.team/docs/goodies#multi-project-schema
 */
export const createTable = pgTableCreator((name) => `wine-shop_${name}`);

export const posts = createTable(
  "post",
  {
    id: uuid('id').primaryKey(),
    post: text('post').notNull(),
    createdAt: timestamp('createdAt').defaultNow().notNull(),
    updatedAt: timestamp('updatedAt').defaultNow()
  },
  (posts) => {
    return {
      uniqueIdx: uniqueIndex('unique_idx').on(posts.id),
    };
  },
);
